@@ -19,6 +19,7 @@ static ClutterActor* view_to_go_when_end; //After start this points themeselecti
 
 static gchar* prefix_for_saving; //This will contain theme-name, -variation and easy/advanced-mode
 
+static GList* animation_timelines; /*This is container for animation timelines of samplebuttons*/
 
 static gboolean save_composition() { 
 	printf("Saving composition\n");
@@ -153,8 +154,6 @@ return sin (phasing(clutter_timeline_get_progress (clutter_alpha_get_timeline (a
 }
 
 
-static GList* animation_timelines; /*This is container for animation timelines of samplebuttons*/
-
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
 */
@@ -303,6 +302,7 @@ static gboolean no_ready_clicked ( gpointer data) {
 	return FALSE;
 }
 
+static gboolean mentor_has_asked_is_it_ready = FALSE;
 static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button) {
 	const gchar* last_state_of_button = clutter_actor_get_name(CLUTTER_ACTOR(play_button));
 	if (strncmp(last_state_of_button,"play",4)==0) //False alert
@@ -322,13 +322,16 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button
 	clutter_actor_set_name(CLUTTER_ACTOR(play_button),"play");
 	
 	
-	
-	trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(play_button))),
+	if (mentor_has_asked_is_it_ready==FALSE)
+		{
+		trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(play_button))),
                       "/opt/jammo/mentor_speech/mentor_composing_is_it_ready.ogg",
                       "/opt/jammo/mentor_speech/mentor_composing_is_it_ready_idle.ogg",
                       yes_ready_clicked,play_button,
                       no_ready_clicked, NULL
                      );
+		mentor_has_asked_is_it_ready=TRUE;
+		}
 }
 
 
@@ -487,6 +490,15 @@ static void quitting_composing(TangleActor *actor, ClutterActorBox *arg1, Clutte
 		{
 		printf("hiding -> destroy\n");
 		g_signal_handler_disconnect (actor,handler_for_view_transition);
+
+		GList *timeline;
+		for (timeline = animation_timelines;timeline;timeline = timeline->next)
+			{
+			clutter_timeline_set_loop (CLUTTER_TIMELINE(timeline->data),FALSE); //Animations will stop and send completed, and then they are free'ed
+			}
+
+		g_list_free(animation_timelines);
+
 		clutter_actor_destroy(CLUTTER_ACTOR(actor));
 		first_time_transition_completed=TRUE; //For next round.
 		}
@@ -499,8 +511,8 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	printf("Theme '%s' starting.\n",name);
 
 	GError* error = NULL;
-
-
+	animation_timelines=NULL;
+	mentor_has_asked_is_it_ready=FALSE;
 	
 	prefix_for_saving = g_strdup_printf("+%s+%d+%s",name,variation,chum_is_easy_game()? "e":"a");
 	//example: +fantasy+2+e
